@@ -1,5 +1,5 @@
 import test from 'ava';
-import pTry from '.';
+import pTry from './index.js';
 
 const fixture = Symbol('fixture');
 const fixtureError = new Error('fixture');
@@ -7,11 +7,18 @@ const fixtureError = new Error('fixture');
 test('main', async t => {
 	t.is(await pTry(() => fixture), fixture);
 
-	await t.throwsAsync(pTry(() => Promise.reject(fixtureError)), fixtureError.message);
+	await t.throwsAsync(
+		pTry(() => Promise.reject(fixtureError)),
+		{
+			message: fixtureError.message,
+		},
+	);
 
 	await t.throwsAsync(pTry(() => {
 		throw fixtureError;
-	}), fixtureError.message);
+	}), {
+		message: fixtureError.message,
+	});
 });
 
 test('allows passing arguments through', async t => {
